@@ -38,6 +38,7 @@ static void meta_window_present_delete_dialog (MetaWindow *window);
 static void
 delete_ping_reply_func (MetaDisplay *display,
                         Window       xwindow,
+                        Time         timestamp,
                         void        *user_data)
 {
   meta_topic (META_DEBUG_PING,
@@ -290,14 +291,16 @@ io_from_ping_dialog (GIOChannel   *channel,
 static void
 delete_ping_timeout_func (MetaDisplay *display,
                           Window       xwindow,
+                          Time         timestamp,
                           void        *user_data)
 {
   MetaWindow *window = user_data;
   GError *err;
   int child_pid;
   int outpipe;
-  char *argv[7];
+  char *argv[9];
   char numbuf[32];
+  char timestampbuf[32];
   char *window_id_str;
   GIOChannel *channel;
   
@@ -314,14 +317,17 @@ delete_ping_timeout_func (MetaDisplay *display,
   window_id_str = g_strdup_printf ("0x%lx", window->xwindow);
 
   sprintf (numbuf, "%d", window->screen->number);
+  sprintf (timestampbuf, "%lu", timestamp);
   
   argv[0] = METACITY_LIBEXECDIR"/metacity-dialog";
   argv[1] = "--screen";
   argv[2] = numbuf;
-  argv[3] = "--kill-window-question";
-  argv[4] = window->title;
-  argv[5] = window_id_str;
-  argv[6] = NULL;
+  argv[3] = "--timestamp";
+  argv[4] = timestampbuf;
+  argv[5] = "--kill-window-question";
+  argv[6] = window->title;
+  argv[7] = window_id_str;
+  argv[8] = NULL;
   
   err = NULL;
   if (!g_spawn_async_with_pipes ("/",
