@@ -271,7 +271,9 @@ meta_session_init (const char *previous_client_id,
   
   if (session_connection == NULL)
     {
-      meta_warning (_("Failed to a open connection to a session manager, so window positions will not be saved: %s\n"), buf);
+      meta_topic (META_DEBUG_SM, 
+                  "Failed to a open connection to a session manager, so window positions will not be saved: %s\n",
+                  buf);
 
       goto out;
     }
@@ -1849,6 +1851,8 @@ warn_about_lame_clients_and_finish_interact (gboolean shutdown)
   GError *err;
   GIOChannel *channel;
   LameClientsDialogData *d;
+  Time timestamp;
+  char timestampbuf[32];
   
   lame = NULL;
   displays = meta_displays_list ();
@@ -1891,8 +1895,12 @@ warn_about_lame_clients_and_finish_interact (gboolean shutdown)
   
   lame = g_slist_sort (lame, (GCompareFunc) windows_cmp_by_title);
 
+  timestamp = 0;
+  sprintf (timestampbuf, "%lu", timestamp);
+
   len = g_slist_length (lame);
   len *= 2; /* titles and also classes */
+  len += 2; /* --timestamp flag and actual timestamp */
   len += 1; /* NULL term */
   len += 2; /* metacity-dialog command and option */
   
@@ -1902,6 +1910,10 @@ warn_about_lame_clients_and_finish_interact (gboolean shutdown)
 
   argv[i] = METACITY_LIBEXECDIR"/metacity-dialog";
   ++i;
+  argv[i] = "--timestamp";
+  ++i;
+  argv[i] = timestampbuf;
+  ++i;
   argv[i] = "--warn-about-no-sm-support";
   ++i;
   
